# coding: utf-8

"""
    Orbital transfer API

    Orbital transfer API

    The version of the OpenAPI document: 0.0.6
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from orbital_transfer.models.orbit_orekit_parameters import OrbitOrekitParameters

class TestOrbitOrekitParameters(unittest.TestCase):
    """OrbitOrekitParameters unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> OrbitOrekitParameters:
        """Test OrbitOrekitParameters
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OrbitOrekitParameters`
        """
        model = OrbitOrekitParameters()
        if include_optional:
            return OrbitOrekitParameters(
                type = 'CARTESIAN',
                frame = orbital_transfer.models.frame.Frame(
                    name = '', 
                    parent = orbital_transfer.models.frame.Frame(
                        name = '', 
                        depth = 56, 
                        pseudo_inertial = True, ), 
                    depth = 56, 
                    pseudo_inertial = True, ),
                var_date = '',
                mu = 1.337,
                pv_coordinates = orbital_transfer.models.time_stamped_pv_coordinates.TimeStampedPVCoordinates(
                    date = '', 
                    position = orbital_transfer.models.vector3_d.Vector3D(
                        x = 1.337, 
                        y = 1.337, 
                        z = 1.337, ), 
                    velocity = orbital_transfer.models.vector3_d.Vector3D(
                        x = 1.337, 
                        y = 1.337, 
                        z = 1.337, ), 
                    acceleration = , )
            )
        else:
            return OrbitOrekitParameters(
        )
        """

    def testOrbitOrekitParameters(self):
        """Test OrbitOrekitParameters"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
