# coding: utf-8

"""
    Orbital transfer API

    Orbital transfer API

    The version of the OpenAPI document: 0.0.6
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from orbital_transfer.models.orbit import Orbit

class TestOrbit(unittest.TestCase):
    """Orbit unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Orbit:
        """Test Orbit
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Orbit`
        """
        model = Orbit()
        if include_optional:
            return Orbit(
                inclination = 1.337,
                sma = 1.337,
                eccentricity = 1.337,
                parameters = orbital_transfer.models.orbit_parameters.OrbitParameters(),
                advanced_parameters = orbital_transfer.models.advanced_orbit_parameters.AdvancedOrbitParameters(
                    orbit_date = '', 
                    ascending_node_type = 'RAAN', 
                    raan = 1.337, 
                    mltan = 1.337, 
                    anomaly = 1.337, 
                    anomaly_type = 'TRUE', 
                    orbital_element_type = 'MEAN', 
                    perigee_argument = 1.337, )
            )
        else:
            return Orbit(
        )
        """

    def testOrbit(self):
        """Test Orbit"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
