# coding: utf-8

"""
    Orbital transfer API

    Orbital transfer API

    The version of the OpenAPI document: 0.0.6
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from orbital_transfer.models.rotation import Rotation

class TestRotation(unittest.TestCase):
    """Rotation unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Rotation:
        """Test Rotation
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Rotation`
        """
        model = Rotation()
        if include_optional:
            return Rotation(
                q0 = 1.337,
                q1 = 1.337,
                q2 = 1.337,
                q3 = 1.337
            )
        else:
            return Rotation(
        )
        """

    def testRotation(self):
        """Test Rotation"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
