# coding: utf-8

"""
    Orbital transfer API

    Orbital transfer API

    The version of the OpenAPI document: 0.0.6
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from orbital_transfer.api.default_api import DefaultApi


class TestDefaultApi(unittest.TestCase):
    """DefaultApi unit test stubs"""

    def setUp(self) -> None:
        self.api = DefaultApi()

    def tearDown(self) -> None:
        pass

    def test_compute_analytical_orbital_transfer(self) -> None:
        """Test case for compute_analytical_orbital_transfer

        compute analytical orbital transfer
        """
        pass

    def test_compute_numerical_orbital_transfer(self) -> None:
        """Test case for compute_numerical_orbital_transfer

        compute numerical orbital transfer
        """
        pass


if __name__ == '__main__':
    unittest.main()
