# coding: utf-8

"""
    Orbital transfer API

    Orbital transfer API

    The version of the OpenAPI document: 0.0.6
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing import Optional, Set
from typing_extensions import Self

class AnalyticalOrbitalTransferResult(BaseModel):
    """
    AnalyticalOrbitalTransferResult
    """ # noqa: E501
    delta_v: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="deltaV")
    delta_inclination: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="deltaInclination")
    delta_semi_major_axis: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="deltaSemiMajorAxis")
    delta_eccentricity: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="deltaEccentricity")
    maneuvering_duration: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="maneuveringDuration")
    mission_duration: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="missionDuration")
    thrust_duration: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="thrustDuration")
    thruster_mean_duty_cycle: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="thrusterMeanDutyCycle")
    total_impulse: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="totalImpulse")
    used_propellant: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="usedPropellant")
    number_of_burns: Optional[StrictInt] = Field(default=None, alias="numberOfBurns")
    mean_burn_duration_estimation: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="meanBurnDurationEstimation")
    drag_perturbation_enabled: Optional[StrictBool] = Field(default=None, alias="dragPerturbationEnabled")
    mean_atmospheric_density: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="meanAtmosphericDensity")
    mean_drag: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="meanDrag")
    mean_drag_acceleration: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="meanDragAcceleration")
    drag_to_thrust_ratio: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="dragToThrustRatio")
    drag_delta_v: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="dragDeltaV")
    maneuver_model: Optional[StrictStr] = Field(default=None, alias="maneuverModel")
    errors: Optional[List[StrictStr]] = None
    warnings: Optional[List[StrictStr]] = None
    computation_date: Optional[StrictStr] = Field(default=None, alias="computationDate")
    __properties: ClassVar[List[str]] = ["deltaV", "deltaInclination", "deltaSemiMajorAxis", "deltaEccentricity", "maneuveringDuration", "missionDuration", "thrustDuration", "thrusterMeanDutyCycle", "totalImpulse", "usedPropellant", "numberOfBurns", "meanBurnDurationEstimation", "dragPerturbationEnabled", "meanAtmosphericDensity", "meanDrag", "meanDragAcceleration", "dragToThrustRatio", "dragDeltaV", "maneuverModel", "errors", "warnings", "computationDate"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AnalyticalOrbitalTransferResult from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AnalyticalOrbitalTransferResult from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "deltaV": obj.get("deltaV"),
            "deltaInclination": obj.get("deltaInclination"),
            "deltaSemiMajorAxis": obj.get("deltaSemiMajorAxis"),
            "deltaEccentricity": obj.get("deltaEccentricity"),
            "maneuveringDuration": obj.get("maneuveringDuration"),
            "missionDuration": obj.get("missionDuration"),
            "thrustDuration": obj.get("thrustDuration"),
            "thrusterMeanDutyCycle": obj.get("thrusterMeanDutyCycle"),
            "totalImpulse": obj.get("totalImpulse"),
            "usedPropellant": obj.get("usedPropellant"),
            "numberOfBurns": obj.get("numberOfBurns"),
            "meanBurnDurationEstimation": obj.get("meanBurnDurationEstimation"),
            "dragPerturbationEnabled": obj.get("dragPerturbationEnabled"),
            "meanAtmosphericDensity": obj.get("meanAtmosphericDensity"),
            "meanDrag": obj.get("meanDrag"),
            "meanDragAcceleration": obj.get("meanDragAcceleration"),
            "dragToThrustRatio": obj.get("dragToThrustRatio"),
            "dragDeltaV": obj.get("dragDeltaV"),
            "maneuverModel": obj.get("maneuverModel"),
            "errors": obj.get("errors"),
            "warnings": obj.get("warnings"),
            "computationDate": obj.get("computationDate")
        })
        return _obj


