# coding: utf-8

"""
    Orbital transfer API

    Orbital transfer API

    The version of the OpenAPI document: 0.0.6
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing import Optional, Set
from typing_extensions import Self

class PropulsionSystem(BaseModel):
    """
    PropulsionSystem
    """ # noqa: E501
    isp: Optional[Union[StrictFloat, StrictInt]] = None
    power: Optional[Union[StrictFloat, StrictInt]] = None
    thrust: Optional[Union[StrictFloat, StrictInt]] = None
    standby_power: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="standbyPower")
    warm_up_power: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="warmUpPower")
    warm_up_duration: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="warmUpDuration")
    propellant_mass: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="propellantMass")
    total_mass: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="totalMass")
    total_impulse: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="totalImpulse")
    maximum_thrust_duration: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="maximumThrustDuration")
    propellant_capacity_choice: Optional[StrictStr] = Field(default=None, alias="propellantCapacityChoice")
    propulsion_system_type: Optional[StrictStr] = Field(default=None, alias="propulsionSystemType")
    __properties: ClassVar[List[str]] = ["isp", "power", "thrust", "standbyPower", "warmUpPower", "warmUpDuration", "propellantMass", "totalMass", "totalImpulse", "maximumThrustDuration", "propellantCapacityChoice", "propulsionSystemType"]

    @field_validator('propellant_capacity_choice')
    def propellant_capacity_choice_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['PROPELLANT', 'TOTAL_IMPULSE']):
            raise ValueError("must be one of enum values ('PROPELLANT', 'TOTAL_IMPULSE')")
        return value

    @field_validator('propulsion_system_type')
    def propulsion_system_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['CHEMICAL', 'ELECTRICAL']):
            raise ValueError("must be one of enum values ('CHEMICAL', 'ELECTRICAL')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PropulsionSystem from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PropulsionSystem from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "isp": obj.get("isp"),
            "power": obj.get("power"),
            "thrust": obj.get("thrust"),
            "standbyPower": obj.get("standbyPower"),
            "warmUpPower": obj.get("warmUpPower"),
            "warmUpDuration": obj.get("warmUpDuration"),
            "propellantMass": obj.get("propellantMass"),
            "totalMass": obj.get("totalMass"),
            "totalImpulse": obj.get("totalImpulse"),
            "maximumThrustDuration": obj.get("maximumThrustDuration"),
            "propellantCapacityChoice": obj.get("propellantCapacityChoice"),
            "propulsionSystemType": obj.get("propulsionSystemType")
        })
        return _obj


